pub struct MmaConfig {
pub a_type: StorageType,
pub b_type: StorageType,
pub cd_type: StorageType,
pub m: u32,
pub n: u32,
pub k: u32,
}Expand description
Shape and element types of a valid MMA configuration
Fields
a_type: StorageTypeElement of the A matrix
b_type: StorageTypeElement of the B matrix
cd_type: StorageTypeElement of the C/D matrices
m: u32The size of the matrix on the m dimension
n: u32The size of the matrix on the n dimension
k: u32The size of the matrix on the k dimension