pub struct ScaledMmaConfig {
pub a_type: StorageType,
pub b_type: StorageType,
pub cd_type: StorageType,
pub scales_type: StorageType,
pub m: u32,
pub n: u32,
pub k: u32,
pub scales_factor: u32,
}Expand description
Shape and element types of a valid block-scaled MMA configuration
Fields
a_type: StorageTypeElement of the A matrix
b_type: StorageTypeElement of the B matrix
cd_type: StorageTypeElement of the C/D matrices
scales_type: StorageTypeElement of the blocks scales
m: u32The size of the matrix on the m dimension
n: u32The size of the matrix on the n dimension
k: u32The size of the matrix on the k dimension
scales_factor: u32Number of scales per tile row/col.
A scale factor of 2 means m x 2 scales for A and 2 x n for B (in CUDA)
Scales blocks must be organized along the natural vector_layout of the operation