pub struct Types {
pub address: BTreeSet<AddressType>,
pub storage: BTreeMap<StorageType, EnumSet<TypeUsage>>,
pub semantic: BTreeSet<SemanticType>,
pub atomic: BTreeMap<Type, EnumSet<AtomicUsage>>,
}Expand description
Type support for a device
Fields
address: BTreeSet<AddressType>Valid address types
storage: BTreeMap<StorageType, EnumSet<TypeUsage>>Types supported by this runtime, and which usages they support.
semantic: BTreeSet<SemanticType>Semantic constructs supported by this runtime.
atomic: BTreeMap<Type, EnumSet<AtomicUsage>>Supported vector types for atomic ops, only specific vectorizations for specific types are
supported here. Not all vector types are supported as scalars, i.e. Vulkan on Nvidia only
supports vectorized f16, not scalar. Only use the exact vectorizations registered here.
These may not be supported everywhere - in practice, f32 vectors are only supported in global
memory.