Matrix

Struct Matrix 

pub struct Matrix<C, S = Plane>
where C: CubeType, S: MatrixScope,
{ /* private fields */ }
A matrix represent a 2D grid of numbers.

They can either be in a row major or a column major format.

Implementations

Source

impl<C, S> Matrix<C, S>

pub unsafe fn uninitialized( ident: MatrixIdent, m: usize, n: usize, k: usize, layout: MatrixLayout, ) -> Matrix<C, S>

Create a new uninitialized matrix that is going to be used in the matrix-multiply and accumulate function.

Safety

Must be initialized with load or fill before use. Using it without initialization is undefined behaviour on CUDA, and completely invalid on Vulkan.

You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.

Not all shapes are supported, and the permitted shapes depend on the element type.

Refer to nvidia documentation.

pub fn from_value( ident: MatrixIdent, m: usize, n: usize, k: usize, layout: MatrixLayout, value: C, ) -> Matrix<C, S>
where C: Scalar,

Create a new matrix that is going to be used in the matrix-multiply and accumulate function and is filled with value.

You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.

Not all shapes are supported, and the permitted shapes depend on the element type.

Refer to nvidia documentation.

pub fn from_slice( ident: MatrixIdent, m: usize, n: usize, k: usize, layout: MatrixLayout, value: &[C], stride: u32, ) -> Matrix<C, S>

Create a new matrix that is going to be used in the matrix-multiply and accumulate function and is loaded from value with stride.

You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.

Not all shapes are supported, and the permitted shapes depend on the element type.

Refer to nvidia documentation.

pub fn from_tensor( ident: MatrixIdent, m: usize, n: usize, k: usize, value: &TensorView<C>, ) -> Matrix<C, S>

Create a new matrix that is going to be used in the matrix-multiply and accumulate function and is loaded from value with stride.

You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.

Not all shapes are supported, and the permitted shapes depend on the element type.

Refer to nvidia documentation.

pub fn __expand_uninitialized( scope: &Scope, ident: MatrixIdent, m: usize, n: usize, k: usize, layout: <MatrixLayout as CubeType>::ExpandType, ) -> <Matrix<C, S> as CubeType>::ExpandType

Create a new uninitialized matrix that is going to be used in the matrix-multiply and accumulate function.

Safety

Must be initialized with load or fill before use. Using it without initialization is undefined behaviour on CUDA, and completely invalid on Vulkan.

You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.

Not all shapes are supported, and the permitted shapes depend on the element type.

Refer to nvidia documentation.

pub fn __expand_from_value( scope: &Scope, ident: MatrixIdent, m: usize, n: usize, k: usize, layout: <MatrixLayout as CubeType>::ExpandType, value: <C as CubeType>::ExpandType, ) -> <Matrix<C, S> as CubeType>::ExpandType
where C: Scalar,

Create a new matrix that is going to be used in the matrix-multiply and accumulate function and is filled with value.

You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.

Not all shapes are supported, and the permitted shapes depend on the element type.

Refer to nvidia documentation.

pub fn __expand_from_slice( scope: &Scope, ident: MatrixIdent, m: usize, n: usize, k: usize, layout: <MatrixLayout as CubeType>::ExpandType, value: &<[C] as CubeType>::ExpandType, stride: <u32 as CubeType>::ExpandType, ) -> <Matrix<C, S> as CubeType>::ExpandType

Create a new matrix that is going to be used in the matrix-multiply and accumulate function and is loaded from value with stride.

You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.

Not all shapes are supported, and the permitted shapes depend on the element type.

Refer to nvidia documentation.

pub fn __expand_from_tensor( scope: &Scope, ident: MatrixIdent, m: usize, n: usize, k: usize, value: &<TensorView<C> as CubeType>::ExpandType, ) -> <Matrix<C, S> as CubeType>::ExpandType

Create a new matrix that is going to be used in the matrix-multiply and accumulate function and is loaded from value with stride.

You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.

Not all shapes are supported, and the permitted shapes depend on the element type.

Refer to nvidia documentation.