pub struct NativeExpand<T>where
T: CubeType,{
pub expand: ManagedVariable,
/* private fields */
}Expand description
Expand type of a native GPU type, i.e. scalar primitives, arrays, shared memory.
Fields
expand: ManagedVariableImplementations
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_tma_load_1d_method<C1, C2>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, x: NativeExpand<i32>, )
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_tma_load_2d_method<C1, C2>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, y: NativeExpand<i32>, x: NativeExpand<i32>, )
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_tma_load_3d_method<C1, C2>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_tma_load_4d_method<C1, C2>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, w: NativeExpand<i32>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_tma_load_5d_method<C1, C2>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, v: NativeExpand<i32>, w: NativeExpand<i32>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_tma_load_im2col_3d_method<C1, C2>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Im2col>>, destination: SliceExpand<C2, ReadWrite>, n: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, w_offset: NativeExpand<u16>, )
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_tma_load_im2col_4d_method<C1, C2>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Im2col>>, destination: SliceExpand<C2, ReadWrite>, n: NativeExpand<i32>, h: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, h_offset: NativeExpand<u16>, w_offset: NativeExpand<u16>, )
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_tma_load_im2col_5d_method<C1, C2>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Im2col>>, destination: SliceExpand<C2, ReadWrite>, n: NativeExpand<i32>, d: NativeExpand<i32>, h: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, d_offset: NativeExpand<u16>, h_offset: NativeExpand<u16>, w_offset: NativeExpand<u16>, )
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_init_manual_method( &self, scope: &mut Scope, arrival_count: <u32 as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_local(scope: &mut Scope) -> NativeExpand<Barrier>
pub fn __expand_init_manual( scope: &mut Scope, this: &NativeExpand<Barrier>, arrival_count: <u32 as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_memcpy_async_method<C>(
&self,
scope: &mut Scope,
source: <Slice<C> as CubeType>::ExpandType,
destination: <Slice<C, ReadWrite> as CubeType>::ExpandType,
) -> <() as CubeType>::ExpandTypewhere
C: CubePrimitive,
pub fn __expand_memcpy_async_cooperative_method<C>(
&self,
scope: &mut Scope,
source: <Slice<C> as CubeType>::ExpandType,
destination: <Slice<C, ReadWrite> as CubeType>::ExpandType,
) -> <() as CubeType>::ExpandTypewhere
C: CubePrimitive,
pub fn __expand_memcpy_async_tx_method<C>(
&self,
scope: &mut Scope,
source: <Slice<C> as CubeType>::ExpandType,
destination: <Slice<C, ReadWrite> as CubeType>::ExpandType,
) -> <() as CubeType>::ExpandTypewhere
C: CubePrimitive,
pub fn __expand_memcpy_async<C>(
scope: &mut Scope,
this: &NativeExpand<Barrier>,
source: <Slice<C> as CubeType>::ExpandType,
destination: <Slice<C, ReadWrite> as CubeType>::ExpandType,
) -> <() as CubeType>::ExpandTypewhere
C: CubePrimitive,
pub fn __expand_memcpy_async_cooperative<C>(
scope: &mut Scope,
this: &NativeExpand<Barrier>,
source: <Slice<C> as CubeType>::ExpandType,
destination: <Slice<C, ReadWrite> as CubeType>::ExpandType,
) -> <() as CubeType>::ExpandTypewhere
C: CubePrimitive,
pub fn __expand_memcpy_async_tx<C>(
scope: &mut Scope,
this: &NativeExpand<Barrier>,
source: <Slice<C> as CubeType>::ExpandType,
destination: <Slice<C, ReadWrite> as CubeType>::ExpandType,
) -> <() as CubeType>::ExpandTypewhere
C: CubePrimitive,
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_arrive_method( &self, scope: &mut Scope, ) -> <BarrierToken as CubeType>::ExpandType
pub fn __expand_arrive_and_expect_tx_method( &self, scope: &mut Scope, arrival_count: <u32 as CubeType>::ExpandType, transaction_count: <u32 as CubeType>::ExpandType, ) -> <BarrierToken as CubeType>::ExpandType
pub fn __expand_expect_tx_method( &self, scope: &mut Scope, expected_count: <u32 as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_arrive_and_wait_method( &self, scope: &mut Scope, ) -> <() as CubeType>::ExpandType
pub fn __expand_wait_method( &self, scope: &mut Scope, token: <BarrierToken as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_wait_parity_method( &self, scope: &mut Scope, phase: <u32 as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_arrive( scope: &mut Scope, this: &NativeExpand<Barrier>, ) -> <BarrierToken as CubeType>::ExpandType
pub fn __expand_arrive_and_expect_tx( scope: &mut Scope, this: &NativeExpand<Barrier>, arrival_count: <u32 as CubeType>::ExpandType, transaction_count: <u32 as CubeType>::ExpandType, ) -> <BarrierToken as CubeType>::ExpandType
pub fn __expand_expect_tx( scope: &mut Scope, this: &NativeExpand<Barrier>, expected_count: <u32 as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_arrive_and_wait( scope: &mut Scope, this: &NativeExpand<Barrier>, ) -> <() as CubeType>::ExpandType
pub fn __expand_wait( scope: &mut Scope, this: &NativeExpand<Barrier>, token: <BarrierToken as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_wait_parity( scope: &mut Scope, this: &NativeExpand<Barrier>, phase: <u32 as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
Sourceimpl NativeExpand<Barrier>
impl NativeExpand<Barrier>
pub fn __expand_commit_copy_async_method( &self, scope: &mut Scope, ) -> <() as CubeType>::ExpandType
pub fn __expand_commit_copy_async( scope: &mut Scope, this: &NativeExpand<Barrier>, ) -> <() as CubeType>::ExpandType
Sourceimpl<T> NativeExpand<Array<T>>where
T: CubePrimitive + Clone,
impl<T> NativeExpand<Array<T>>where
T: CubePrimitive + Clone,
pub fn __expand_to_vectorized_method<N>(
self,
scope: &mut Scope,
) -> <T as CubeType>::ExpandTypewhere
N: Size,
pub fn __expand_to_vectorized<N>(
scope: &mut Scope,
this: NativeExpand<Array<T>>,
) -> <T as CubeType>::ExpandTypewhere
N: Size,
Sourceimpl<E> NativeExpand<Array<E>>where
E: CubeType,
impl<E> NativeExpand<Array<E>>where
E: CubeType,
pub fn __expand_len_method( self, scope: &mut Scope, ) -> <usize as CubeType>::ExpandType
pub fn __expand_buffer_len_method( self, scope: &mut Scope, ) -> <usize as CubeType>::ExpandType
pub fn __expand_len( scope: &mut Scope, this: NativeExpand<Array<E>>, ) -> <usize as CubeType>::ExpandType
pub fn __expand_buffer_len( scope: &mut Scope, this: NativeExpand<Array<E>>, ) -> <usize as CubeType>::ExpandType
Sourceimpl<E> NativeExpand<Array<E>>where
E: CubePrimitive,
impl<E> NativeExpand<Array<E>>where
E: CubePrimitive,
pub fn __expand_index_unchecked_method( self, scope: &mut Scope, i: <usize as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType
pub fn __expand_index_assign_unchecked_method( self, scope: &mut Scope, i: <usize as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_index_unchecked( scope: &mut Scope, this: NativeExpand<Array<E>>, i: <usize as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType
pub fn __expand_index_assign_unchecked( scope: &mut Scope, this: NativeExpand<Array<E>>, i: <usize as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_len_method( self, scope: &mut Scope, ) -> <usize as CubeType>::ExpandType
pub fn __expand_buffer_len_method( self, scope: &mut Scope, ) -> <usize as CubeType>::ExpandType
pub fn __expand_new( scope: &mut Scope, size: usize, ) -> NativeExpand<SharedMemory<T>>
pub fn __expand_len( scope: &mut Scope, this: NativeExpand<SharedMemory<T>>, ) -> <usize as CubeType>::ExpandType
pub fn __expand_buffer_len( scope: &mut Scope, this: NativeExpand<SharedMemory<T>>, ) -> <usize as CubeType>::ExpandType
pub fn __expand_free_method( self, scope: &mut Scope, ) -> <() as CubeType>::ExpandType
pub fn __expand_new_aligned( scope: &mut Scope, size: usize, alignment: usize, ) -> <SharedMemory<T> as CubeType>::ExpandType
pub fn __expand_free( scope: &mut Scope, this: NativeExpand<SharedMemory<T>>, ) -> <() as CubeType>::ExpandType
pub fn __expand_index_unchecked_method( self, scope: &mut Scope, i: <usize as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType
pub fn __expand_index_assign_unchecked_method( self, scope: &mut Scope, i: <usize as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_index_unchecked( scope: &mut Scope, this: NativeExpand<SharedMemory<E>>, i: <usize as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType
pub fn __expand_index_assign_unchecked( scope: &mut Scope, this: NativeExpand<SharedMemory<E>>, i: <usize as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
Sourceimpl<T> NativeExpand<Tensor<T>>where
T: CubeType,
impl<T> NativeExpand<Tensor<T>>where
T: CubeType,
pub fn __expand_stride_method( self, scope: &mut Scope, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType
pub fn __expand_shape_method( self, scope: &mut Scope, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType
pub fn __expand_coordinate_method( self, scope: &mut Scope, index: <usize as CubeType>::ExpandType, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType
pub fn __expand_len_method( self, scope: &mut Scope, ) -> <usize as CubeType>::ExpandType
pub fn __expand_buffer_len_method( self, scope: &mut Scope, ) -> <usize as CubeType>::ExpandType
pub fn __expand_rank_method( self, scope: &mut Scope, ) -> <usize as CubeType>::ExpandType
pub fn __expand_stride( scope: &mut Scope, this: NativeExpand<Tensor<T>>, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType
pub fn __expand_shape( scope: &mut Scope, this: NativeExpand<Tensor<T>>, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType
pub fn __expand_coordinate( scope: &mut Scope, this: NativeExpand<Tensor<T>>, index: <usize as CubeType>::ExpandType, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType
pub fn __expand_len( scope: &mut Scope, this: NativeExpand<Tensor<T>>, ) -> <usize as CubeType>::ExpandType
pub fn __expand_buffer_len( scope: &mut Scope, this: NativeExpand<Tensor<T>>, ) -> <usize as CubeType>::ExpandType
pub fn __expand_rank( scope: &mut Scope, this: NativeExpand<Tensor<T>>, ) -> <usize as CubeType>::ExpandType
Sourceimpl<E> NativeExpand<Tensor<E>>where
E: CubePrimitive,
impl<E> NativeExpand<Tensor<E>>where
E: CubePrimitive,
pub fn __expand_index_unchecked_method( self, scope: &mut Scope, i: <usize as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType
pub fn __expand_index_assign_unchecked_method( self, scope: &mut Scope, i: <usize as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_index_unchecked( scope: &mut Scope, this: NativeExpand<Tensor<E>>, i: <usize as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType
pub fn __expand_index_assign_unchecked( scope: &mut Scope, this: NativeExpand<Tensor<E>>, i: <usize as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
Sourceimpl<T, K> NativeExpand<TensorMap<T, K>>where
T: CubePrimitive,
K: TensorMapKind,
impl<T, K> NativeExpand<TensorMap<T, K>>where
T: CubePrimitive,
K: TensorMapKind,
pub fn __expand_buffer_method( self, scope: &mut Scope, ) -> NativeExpand<Tensor<T>>
pub fn __expand_stride_method( self, scope: &mut Scope, dim: NativeExpand<usize>, ) -> NativeExpand<usize>
pub fn __expand_shape_method( self, scope: &mut Scope, dim: NativeExpand<usize>, ) -> NativeExpand<usize>
pub fn __expand_coordinate_method( self, scope: &mut Scope, index: NativeExpand<usize>, dim: NativeExpand<usize>, ) -> NativeExpand<usize>
pub fn __expand_len_method(self, scope: &mut Scope) -> NativeExpand<usize>
pub fn __expand_buffer_len_method( self, scope: &mut Scope, ) -> NativeExpand<usize>
pub fn __expand_rank_method(self, scope: &mut Scope) -> NativeExpand<usize>
Sourcepub fn __expand_downcast_method<E>(
self,
scope: &mut Scope,
) -> NativeExpand<TensorMap<E, K>>where
E: CubePrimitive,
pub fn __expand_downcast_method<E>(
self,
scope: &mut Scope,
) -> NativeExpand<TensorMap<E, K>>where
E: CubePrimitive,
Expand method of TensorMap::downcast.
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
pub fn __expand_fill_method( self, scope: &mut Scope, value: <P as CubeType>::ExpandType, ) -> NativeExpand<Vector<P, N>>
pub fn __expand_fill( scope: &mut Scope, this: NativeExpand<Vector<P, N>>, value: <P as CubeType>::ExpandType, ) -> NativeExpand<Vector<P, N>>
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
pub fn __expand_equal_method( self, scope: &mut Scope, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_equal( scope: &mut Scope, this: NativeExpand<Vector<P, N>>, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
pub fn __expand_not_equal_method( self, scope: &mut Scope, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_not_equal( scope: &mut Scope, this: NativeExpand<Vector<P, N>>, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
pub fn __expand_less_than_method( self, scope: &mut Scope, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_less_than( scope: &mut Scope, this: NativeExpand<Vector<P, N>>, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
pub fn __expand_greater_than_method( self, scope: &mut Scope, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_greater_than( scope: &mut Scope, this: NativeExpand<Vector<P, N>>, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
pub fn __expand_less_equal_method( self, scope: &mut Scope, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_less_equal( scope: &mut Scope, this: NativeExpand<Vector<P, N>>, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
pub fn __expand_greater_equal_method( self, scope: &mut Scope, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_greater_equal( scope: &mut Scope, this: NativeExpand<Vector<P, N>>, other: NativeExpand<Vector<P, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<N> NativeExpand<Vector<bool, N>>where
N: Size,
impl<N> NativeExpand<Vector<bool, N>>where
N: Size,
pub fn __expand_and_method( self, scope: &mut Scope, other: NativeExpand<Vector<bool, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_and( scope: &mut Scope, this: NativeExpand<Vector<bool, N>>, other: NativeExpand<Vector<bool, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<N> NativeExpand<Vector<bool, N>>where
N: Size,
impl<N> NativeExpand<Vector<bool, N>>where
N: Size,
pub fn __expand_or_method( self, scope: &mut Scope, other: NativeExpand<Vector<bool, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_or( scope: &mut Scope, this: NativeExpand<Vector<bool, N>>, other: NativeExpand<Vector<bool, N>>, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> NativeExpand<Vector<P, N>>
impl<P, N> NativeExpand<Vector<P, N>>
pub fn __expand_count_ones_method( self, scope: &mut Scope, ) -> <Vector<u32, N> as CubeType>::ExpandType
pub fn __expand_count_ones( scope: &mut Scope, this: NativeExpand<Vector<P, N>>, ) -> <Vector<u32, N> as CubeType>::ExpandType
Sourceimpl<Inner> NativeExpand<Atomic<Inner>>
impl<Inner> NativeExpand<Atomic<Inner>>
pub fn __expand_load_method( self, scope: &mut Scope, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_store_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_swap_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_add_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_sub_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_max_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_min_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_load( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_store( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_swap( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_add( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_sub( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_max( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_min( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Sourceimpl<Inner> NativeExpand<Atomic<Inner>>
impl<Inner> NativeExpand<Atomic<Inner>>
pub fn __expand_compare_exchange_weak_method( self, scope: &mut Scope, cmp: <Inner as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_and_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_or_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_xor_method( self, scope: &mut Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_compare_exchange_weak( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, cmp: <Inner as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_and( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_or( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_xor( scope: &mut Scope, this: NativeExpand<Atomic<Inner>>, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Sourceimpl<T> NativeExpand<T>where
T: CubeType,
impl<T> NativeExpand<T>where
T: CubeType,
Sourcepub fn new(expand: ManagedVariable) -> NativeExpand<T>
pub fn new(expand: ManagedVariable) -> NativeExpand<T>
Constructs a new NativeExpand.
Sourceimpl<T> NativeExpand<T>where
T: CubeType,
impl<T> NativeExpand<T>where
T: CubeType,
Sourcepub unsafe fn as_type_ref_unchecked<E>(&self) -> &NativeExpand<E>where
E: CubeType,
pub unsafe fn as_type_ref_unchecked<E>(&self) -> &NativeExpand<E>where
E: CubeType,
Casts a reference of this expand element to a different type.
Safety
There’s no guarantee the new type is valid for the ManagedVariable
Sourcepub unsafe fn as_type_mut_unchecked<E>(&mut self) -> &mut NativeExpand<E>where
E: CubeType,
pub unsafe fn as_type_mut_unchecked<E>(&mut self) -> &mut NativeExpand<E>where
E: CubeType,
Casts a mutable reference of this expand element to a different type.
Safety
There’s no guarantee the new type is valid for the ManagedVariable
Sourceimpl<T> NativeExpand<T>where
T: CubeType,
impl<T> NativeExpand<T>where
T: CubeType,
Sourcepub fn vector_size(&self) -> usize
pub fn vector_size(&self) -> usize
Comptime version of crate::frontend::Array::vector_size.
pub fn __expand_vector_size_method(self, _scope: &mut Scope) -> usize
pub fn into_variable(self) -> Variable
Sourceimpl<T> NativeExpand<T>where
T: CubePrimitive,
impl<T> NativeExpand<T>where
T: CubePrimitive,
Sourcepub fn from_lit<L>(scope: &Scope, lit: L) -> NativeExpand<T>where
L: Into<ConstantValue>,
pub fn from_lit<L>(scope: &Scope, lit: L) -> NativeExpand<T>where
L: Into<ConstantValue>,
Create an NativeExpand from a value that is normally a literal.
Sourcepub fn constant(&self) -> Option<ConstantValue>
pub fn constant(&self) -> Option<ConstantValue>
Get the ConstantValue from the variable.
pub fn __expand_into_lit_unchecked_method(self, _scope: &mut Scope) -> T
Sourceimpl<E> NativeExpand<E>where
E: Int,
impl<E> NativeExpand<E>where
E: Int,
pub fn __expand_is_multiple_of_method( self, scope: &mut Scope, factor: NativeExpand<E>, ) -> NativeExpand<bool>