pub struct OrderingExpand { /* private fields */ }Trait Implementations
Sourceimpl Assign for OrderingExpand
impl Assign for OrderingExpand
Sourcefn expand_assign(&mut self, scope: &mut Scope, value: OrderingExpand)
fn expand_assign(&mut self, scope: &mut Scope, value: OrderingExpand)
Assign
value to self in scope.Sourcefn init_mut(&self, scope: &mut Scope) -> OrderingExpand
fn init_mut(&self, scope: &mut Scope) -> OrderingExpand
Create a new mutable variable of this type in
scope.Sourceimpl Clone for OrderingExpand
impl Clone for OrderingExpand
Sourcefn clone(&self) -> OrderingExpand
fn clone(&self) -> OrderingExpand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CubeDebug for OrderingExpand
impl CubeDebug for OrderingExpand
Sourcefn set_debug_name(&self, scope: &mut Scope, name: &'static str)
fn set_debug_name(&self, scope: &mut Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl CubeEnum for OrderingExpand
impl CubeEnum for OrderingExpand
type RuntimeValue = <() as CubeType>::ExpandType
fn discriminant(&self) -> NativeExpand<i32>
Sourcefn runtime_value(self) -> <OrderingExpand as CubeEnum>::RuntimeValue
fn runtime_value(self) -> <OrderingExpand as CubeEnum>::RuntimeValue
Return the runtime value of this enum, if only one variant has a value.
Should return () for all other cases.
fn discriminant_of(variant_name: &'static str) -> i32
fn discriminant_of_value(&self, variant_name: &'static str) -> i32
Sourceimpl IntoMut for OrderingExpand
impl IntoMut for OrderingExpand
Sourcefn into_mut(self, scope: &mut Scope) -> OrderingExpand
fn into_mut(self, scope: &mut Scope) -> OrderingExpand
Convert the variable into a potentially new mutable variable in
scope, copying if needed.Auto Trait Implementations
impl Freeze for OrderingExpand
impl RefUnwindSafe for OrderingExpand
impl !Send for OrderingExpand
impl !Sync for OrderingExpand
impl Unpin for OrderingExpand
impl UnsafeUnpin for OrderingExpand
impl UnwindSafe for OrderingExpand