Sequence

Struct Sequence 

pub struct Sequence<T>
where T: CubeType,
{ /* private fields */ }
A sequence of cube types that is inlined during compilation.

In other words, it allows you to group a dynamic amount of variables at compile time.

All methods push, index and into_iter are executed during compilation and don’t add any overhead on the generated kernel.

Implementations

Source

impl<T> Sequence<T>
where T: CubeType + Clone,

pub fn rev(&self) -> Sequence<T>

Source

impl<T> Sequence<T>
where T: CubeType,

pub fn new() -> Sequence<T>

Create a new empty sequence.

pub fn push(&mut self, value: T)

Push a new value into the sequence.

pub fn len(&self) -> usize

Obtain the sequence length.

pub fn index(&self, index: usize) -> &T

Get the variable at the given position in the sequence.

pub fn index_mut(&mut self, index: usize) -> &mut T

Get the variable at the given position in the sequence.

pub fn __expand_new(_scope: &mut Scope) -> SequenceExpand<T>

Expand function of new.

pub fn insert(&mut self, index: usize, value: T)

Insert an item at the given index.

pub fn __expand_push( scope: &mut Scope, expand: &mut SequenceExpand<T>, value: <T as CubeType>::ExpandType, )

Expand function of push.

pub fn __expand_index( scope: &mut Scope, expand: SequenceExpand<T>, index: usize, ) -> <T as CubeType>::ExpandType

Expand function of index.

pub fn __expand_index_mut( scope: &mut Scope, expand: SequenceExpand<T>, index: usize, ) -> <T as CubeType>::ExpandType

Expand function of index_mut.