pub struct TensorMap<E, K>where
E: CubePrimitive,
K: TensorMapKind,{ /* private fields */ }Expand description
A CUDA CUtensorMap object. Represents a tensor encoded with a lot of metadata, and is an
opaque packed object at runtime. Does not support retrieving any shapes or strides, nor does
it give access to the pointer. So these need to be passed separately in an aliased Tensor if needed.
Also see cubecl_runtime::tma.
Implementations
Sourceimpl<T, K> TensorMap<T, K>where
T: Scalar,
K: TensorMapKind,
impl<T, K> TensorMap<T, K>where
T: Scalar,
K: TensorMapKind,
Sourcepub fn buffer<N>(&self) -> Tensor<Vector<T, N>> ⓘwhere
N: Size,
pub fn buffer<N>(&self) -> Tensor<Vector<T, N>> ⓘwhere
N: Size,
Get a reference to the underlying buffer for the tensor map.
Sourcepub fn coordinate(&self, _index: usize, _dim: usize) -> usize
pub fn coordinate(&self, _index: usize, _dim: usize) -> usize
Obtain the coordinate corresponding to the given index of the tensor at dimension dim.
A coordinate is a list of indices corresponding to the multi-dimensional position of an element in the tensor.
The dim element in a coordinate is the position along the dim dimension of the tensor.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
The number of vectorized elements in the tensor.
Warning
The length will be affected by the vectorization factor. To obtain the number of elements, you should multiply the length by the vectorization factor.
Sourcepub fn buffer_len(&self) -> usize
pub fn buffer_len(&self) -> usize
The length of the buffer representing the tensor in terms of vectorized elements.
Warning
The buffer length will be affected by the vectorization factor. To obtain the number of elements, you should multiply the length by the vectorization factor.
Sourcepub fn downcast<E>(&self) -> TensorMap<E, K>where
E: CubePrimitive,
pub fn downcast<E>(&self) -> TensorMap<E, K>where
E: CubePrimitive,
Downcast the tensormap to the given type and panic if the type isn’t the same.
This function should only be used to satisfy the Rust type system, when two generic types are supposed to be the same.
pub fn __expand_buffer( scope: &mut Scope, expand: NativeExpand<TensorMap<T, K>>, ) -> NativeExpand<Tensor<T>>
pub fn __expand_stride( scope: &mut Scope, expand: NativeExpand<TensorMap<T, K>>, dim: NativeExpand<usize>, ) -> NativeExpand<usize>
pub fn __expand_shape( scope: &mut Scope, expand: NativeExpand<TensorMap<T, K>>, dim: NativeExpand<usize>, ) -> NativeExpand<usize>
pub fn __expand_coordinate( scope: &mut Scope, expand: NativeExpand<TensorMap<T, K>>, index: NativeExpand<usize>, dim: NativeExpand<usize>, ) -> NativeExpand<usize>
pub fn __expand_len( scope: &mut Scope, expand: NativeExpand<TensorMap<T, K>>, ) -> NativeExpand<usize>
pub fn __expand_buffer_len( scope: &mut Scope, expand: NativeExpand<TensorMap<T, K>>, ) -> NativeExpand<usize>
pub fn __expand_rank( scope: &mut Scope, expand: NativeExpand<TensorMap<T, K>>, ) -> NativeExpand<usize>