pub struct TensorMapArg<R, K>where
R: Runtime,
K: TensorMapKind,{
pub tensor: TensorArg<R>,
pub metadata: TensorMapMeta,
pub _kind: PhantomData<K>,
}Expand description
Grid constant tensor map, currently only maps to CUDA tensormap. May be interleaved or swizzled, but last dimension must be contiguous (since strides don’t include the last dimension).
The tensormap is treated as an opaque type at runtime.
Fields
tensor: TensorArg<R>metadata: TensorMapMeta_kind: PhantomData<K>Implementations
Sourceimpl<R, K> TensorMapArg<R, K>where
R: Runtime,
K: TensorMapKind,
impl<R, K> TensorMapArg<R, K>where
R: Runtime,
K: TensorMapKind,
pub fn new( args: <K as TensorMapKind>::Args, tensor: TensorArg<R>, ty: impl Into<Type>, ) -> TensorMapArg<R, K>
pub fn with_elem_stride(self, elem_stride: Strides) -> TensorMapArg<R, K>
pub fn with_interleave( self, interleave: TensorMapInterleave, ) -> TensorMapArg<R, K>
pub fn with_swizzle(self, swizzle: TensorMapSwizzle) -> TensorMapArg<R, K>
pub fn with_prefetch(self, prefetch: TensorMapPrefetch) -> TensorMapArg<R, K>
pub fn with_nan_fill(self) -> TensorMapArg<R, K>