pub enum BarrierOps {
Show 16 variants
Declare {
barrier: Variable,
},
Init {
barrier: Variable,
is_elected: Variable,
arrival_count: Variable,
},
InitManual {
barrier: Variable,
arrival_count: Variable,
},
MemCopyAsync {
barrier: Variable,
source: Variable,
source_length: Variable,
offset_source: Variable,
offset_out: Variable,
},
MemCopyAsyncCooperative {
barrier: Variable,
source: Variable,
source_length: Variable,
offset_source: Variable,
offset_out: Variable,
},
MemCopyAsyncTx {
barrier: Variable,
source: Variable,
source_length: Variable,
offset_source: Variable,
offset_out: Variable,
},
CopyAsync {
source: Variable,
source_length: Variable,
offset_source: Variable,
offset_out: Variable,
copy_length: u32,
checked: bool,
},
TmaLoad {
barrier: Variable,
tensor_map: Variable,
indices: Vec<Variable>,
offset_out: Variable,
},
TmaLoadIm2col {
barrier: Variable,
tensor_map: Variable,
indices: Vec<Variable>,
offsets: Vec<Variable>,
offset_out: Variable,
},
Arrive {
barrier: Variable,
},
ArriveTx {
barrier: Variable,
arrive_count_update: Variable,
transaction_count_update: Variable,
},
CommitCopyAsync {
barrier: Variable,
},
ExpectTx {
barrier: Variable,
transaction_count_update: Variable,
},
Wait {
barrier: Variable,
token: Variable,
},
WaitParity {
barrier: Variable,
phase: Variable,
},
ArriveAndWait {
barrier: Variable,
},
}Expand description
Operations available on a barrier
Variants
Declare
Declare the barrier, without doing any initialization
Init
Initialize the barrier, optionally with a cta proxy fence
InitManual
Manually initialize the barrier with an arrival count, without any sync or election handling
MemCopyAsync
Copy source to destination
Fields
MemCopyAsyncCooperative
Copy source to destination, with cooperative behaviour
Fields
MemCopyAsyncTx
Copy source to destination, with transaction count
Fields
CopyAsync
Copy source to destination
Fields
TmaLoad
TmaLoadIm2col
Fields
Arrive
Arrives at the barrier (decrements barrier count)
ArriveTx
CommitCopyAsync
ExpectTx
Wait
WaitParity
ArriveAndWait
Waits until data is loaded