pub enum ElemType {
Float(FloatKind),
Int(IntKind),
UInt(UIntKind),
Bool,
}Expand description
Conceptual element type, not necessarily the physical type used in the code
Variants
Implementations
Sourceimpl ElemType
impl ElemType
Sourcepub fn from_quant_param(quant_param: QuantParam) -> ElemType
pub fn from_quant_param(quant_param: QuantParam) -> ElemType
Creates an elem type that correspond to the given QuantParam.
Sourcepub fn from_quant_value(quant_value: QuantValue) -> ElemType
pub fn from_quant_value(quant_value: QuantValue) -> ElemType
Creates an elem type that correspond to the given QuantValue.
Sourcepub fn constant(&self, val: ConstantValue) -> Variable
pub fn constant(&self, val: ConstantValue) -> Variable
Create a constant from a constant value.
The output will have the same type as the element.
pub const fn min_vector_size(&self) -> u8
pub fn is_int(&self) -> bool
pub fn is_signed_int(&self) -> bool
pub fn is_unsigned_int(&self) -> bool
pub fn is_float(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn as_float(&self) -> Option<FloatKind>
pub fn max_variable(&self) -> Variable
pub fn min_variable(&self) -> Variable
pub fn epsilon(&self) -> f64