pub enum Metadata {
Rank {
var: Variable,
},
Stride {
dim: Variable,
var: Variable,
},
Shape {
dim: Variable,
var: Variable,
},
Length {
var: Variable,
},
BufferLength {
var: Variable,
},
}Expand description
All metadata that can be accessed in a shader.
Variants
Rank
The rank of an array.
Stride
The stride of an array at the given dimension.
Shape
The shape of an array at the given dimension.
Length
The length of an array.
BufferLength
The length of an array’s underlying buffer.