pub struct ChunksExactMut<'a, T>where
T: 'a,{ /* private fields */ }Expand description
An iterator over a slice in (non-overlapping) mutable chunks (chunk_size
elements at a time), starting at the beginning of the slice.
When the slice len is not evenly divided by the chunk size, the last up to
chunk_size-1 elements will be omitted but can be retrieved from the
into_remainder function from the iterator.
This struct is created by the chunks_exact_mut method on slices.
Example
let mut slice = ['l', 'o', 'r', 'e', 'm'];
let iter = slice.chunks_exact_mut(2);Implementations
Sourceimpl<'a, T> ChunksExactMut<'a, T>
impl<'a, T> ChunksExactMut<'a, T>
1.31.0 · Sourcepub fn into_remainder(self) -> &'a mut [T]
pub fn into_remainder(self) -> &'a mut [T]
Returns the remainder of the original slice that is not going to be
returned by the iterator. The returned slice has at most chunk_size-1
elements.