pub struct MmaProperties {
pub register_size_bits: usize,
pub const_plane_size: u32,
pub register_layout_a: MatrixLayout,
pub register_layout_b: MatrixLayout,
pub register_layout_acc: MatrixLayout,
pub register_duplication_a: usize,
pub register_duplication_b: usize,
pub register_duplication_acc: usize,
pub contiguous_elements: ContiguousElements,
}Fields
register_size_bits: usizeSize of registers in bits, used to calculate vector size
const_plane_size: u32Constant size of planes, for calculating lane indices in a matrix
register_layout_a: MatrixLayoutLayout of registers in Matrix A
register_layout_b: MatrixLayoutLayout of registers in Matrix B
register_layout_acc: MatrixLayoutLayout of registers in Matrix C/D
register_duplication_a: usizeHow many copies of each piece of data exist for matrix A
register_duplication_b: usizeHow many copies of each piece of data exist for matrix B
register_duplication_acc: usizeHow many copies of each piece of data exist for matrix C/D
contiguous_elements: ContiguousElementsTrait Implementations
Sourceimpl Clone for MmaProperties
impl Clone for MmaProperties
Sourcefn clone(&self) -> MmaProperties
fn clone(&self) -> MmaProperties
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MmaProperties
impl Debug for MmaProperties
Sourceimpl Default for MmaProperties
impl Default for MmaProperties
Sourcefn default() -> MmaProperties
fn default() -> MmaProperties
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MmaProperties
impl<'de> Deserialize<'de> for MmaProperties
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MmaProperties, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MmaProperties, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MmaProperties
impl PartialEq for MmaProperties
Sourcefn eq(&self, other: &MmaProperties) -> bool
fn eq(&self, other: &MmaProperties) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MmaProperties
impl Serialize for MmaProperties
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TypeHash for MmaProperties
impl TypeHash for MmaProperties
impl Eq for MmaProperties
impl StructuralPartialEq for MmaProperties