Variable

Struct Variable 

pub struct Variable {
    pub kind: VariableKind,
    pub ty: Type,
}

Fields

kind: VariableKindty: Type

Implementations

Source

impl Variable

pub fn new(kind: VariableKind, item: Type) -> Variable

pub fn builtin(builtin: Builtin, ty: StorageType) -> Variable

pub fn constant(value: ConstantValue, ty: impl Into<Type>) -> Variable

pub fn elem_type(&self) -> ElemType

pub fn storage_type(&self) -> StorageType

Source

impl Variable

pub fn is_immutable(&self) -> bool

Whether a variable is always immutable. Used for optimizations to determine whether it’s safe to inline/merge

pub fn is_array(&self) -> bool

Is this an array type that yields items when indexed, or a scalar/vector that yields elems/slices when indexed?

pub fn is_memory(&self) -> bool

Is this an array type that is contained in concrete memory, or a local array/scalar/vector?

pub fn has_length(&self) -> bool

pub fn has_buffer_length(&self) -> bool

pub fn is_constant(&self, value: i64) -> bool

Determines if the value is a constant with the specified value (converted if necessary)

pub fn is_true(&self) -> bool

Determines if the value is a boolean constant with the true value

pub fn is_false(&self) -> bool

Determines if the value is a boolean constant with the false value

Source

impl Variable

pub fn vector_size(&self) -> usize

pub fn index(&self) -> Option<u32>

pub fn as_const(&self) -> Option<ConstantValue>