OperationReflect

Trait OperationReflect 

pub trait OperationReflect: Sized {
    type OpCode;

    // Required method
    fn op_code(&self) -> Self::OpCode;

    // Provided methods
    fn args(&self) -> Option<Vec<Variable>> { ... }
    fn from_code_and_args(
        op_code: Self::OpCode,
        args: &[Variable],
    ) -> Option<Self> { ... }
    fn is_commutative(&self) -> bool { ... }
    fn is_pure(&self) -> bool { ... }
}
An operation that can be reflected on

Required Associated Types

type OpCode

Type of the op codes for this operation

Required Methods

fn op_code(&self) -> Self::OpCode

Get the opcode for this operation

Provided Methods

fn args(&self) -> Option<Vec<Variable>>

Get the list of arguments for this operation. If not all arguments are Variable, returns None instead.

fn from_code_and_args(op_code: Self::OpCode, args: &[Variable]) -> Option<Self>

Create typed operation from an opcode and a list of arguments. Returns None if not all arguments are Variable.

fn is_commutative(&self) -> bool

Whether this operation is commutative (arguments can be freely reordered). Ignored for single argument operations.

fn is_pure(&self) -> bool

Whether this operation is pure (has no side effects). Things like uniform/plane operations are considered impure, because they affect other units.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors