pub fn plane_max<E>(_elem: E) -> Ewhere
E: CubePrimitive,Expand description
Perform a reduce max operation across all units in a plane.
pub fn plane_max<E>(_elem: E) -> Ewhere
E: CubePrimitive,Perform a reduce max operation across all units in a plane.