pub struct Vector<P, N>{ /* private fields */ }Expand description
A contiguous list of elements that supports auto-vectorized operations.
Implementations
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
pub fn __expand_new( scope: &mut Scope, val: NativeExpand<P>, ) -> NativeExpand<Vector<P, N>>
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn vector_size(&self) -> usize
pub fn vector_size(&self) -> usize
Get the length of the current vector.
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
pub fn min_value() -> Vector<P, N>
pub fn max_value() -> Vector<P, N>
Sourcepub fn from_int(val: i64) -> Vector<P, N>
pub fn from_int(val: i64) -> Vector<P, N>
Create a new constant numeric.
Note: since this must work for both integer and float
only the less expressive of both can be created (int)
If a number with decimals is needed, use Float::new.
This method panics when unexpanded. For creating an element with a val, use the new method of the sub type.
pub fn __expand_min_value( scope: &mut Scope, ) -> <Vector<P, N> as CubeType>::ExpandType
pub fn __expand_max_value( scope: &mut Scope, ) -> <Vector<P, N> as CubeType>::ExpandType
pub fn __expand_from_int( scope: &mut Scope, val: <i64 as CubeType>::ExpandType, ) -> <Vector<P, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn fill(self, value: P) -> Vector<P, N>
pub fn fill(self, value: P) -> Vector<P, N>
Fill the vector with the given value.
If you want to fill the vector with different values, consider using the index API instead.
let mut vector = Vector::<u32>::empty(2);
vector[0] = 1;
vector[1] = 2;pub fn __expand_fill( scope: &mut Scope, this: <Vector<P, N> as CubeType>::ExpandType, value: <P as CubeType>::ExpandType, ) -> <Vector<P, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
pub fn empty() -> Vector<P, N>
pub fn __expand_empty( scope: &mut Scope, ) -> <Vector<P, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
pub fn zeroed() -> Vector<P, N>
pub fn __expand_zeroed( scope: &mut Scope, ) -> <Vector<P, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn size(&self) -> usize
pub fn size(&self) -> usize
Get the number of individual elements a vector contains.
The size is available at comptime and may be used in combination with the comptime macro.
// The if statement is going to be executed at comptime.
if comptime!(vector.size() == 1) {
}Sourcepub fn __expand_size(
scope: &mut Scope,
element: NativeExpand<Vector<P, N>>,
) -> usize
pub fn __expand_size( scope: &mut Scope, element: NativeExpand<Vector<P, N>>, ) -> usize
Expand function of size.
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn equal(self, other: Vector<P, N>) -> Vector<bool, N>
pub fn equal(self, other: Vector<P, N>) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being equal to the second vector.
pub fn __expand_equal( scope: &mut Scope, this: <Vector<P, N> as CubeType>::ExpandType, other: <Vector<P, N> as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn not_equal(self, other: Vector<P, N>) -> Vector<bool, N>
pub fn not_equal(self, other: Vector<P, N>) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being not equal to the second vector.
pub fn __expand_not_equal( scope: &mut Scope, this: <Vector<P, N> as CubeType>::ExpandType, other: <Vector<P, N> as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn less_than(self, other: Vector<P, N>) -> Vector<bool, N>
pub fn less_than(self, other: Vector<P, N>) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being less than the second vector.
pub fn __expand_less_than( scope: &mut Scope, this: <Vector<P, N> as CubeType>::ExpandType, other: <Vector<P, N> as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn greater_than(self, other: Vector<P, N>) -> Vector<bool, N>
pub fn greater_than(self, other: Vector<P, N>) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being greater than the second vector.
pub fn __expand_greater_than( scope: &mut Scope, this: <Vector<P, N> as CubeType>::ExpandType, other: <Vector<P, N> as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn less_equal(self, other: Vector<P, N>) -> Vector<bool, N>
pub fn less_equal(self, other: Vector<P, N>) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being less than or equal to the second vector.
pub fn __expand_less_equal( scope: &mut Scope, this: <Vector<P, N> as CubeType>::ExpandType, other: <Vector<P, N> as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
Sourcepub fn greater_equal(self, other: Vector<P, N>) -> Vector<bool, N>
pub fn greater_equal(self, other: Vector<P, N>) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being greater than or equal to the second vector.
pub fn __expand_greater_equal( scope: &mut Scope, this: <Vector<P, N> as CubeType>::ExpandType, other: <Vector<P, N> as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<N> Vector<bool, N>where
N: Size,
impl<N> Vector<bool, N>where
N: Size,
Sourcepub fn and(self, other: Vector<bool, N>) -> Vector<bool, N>
pub fn and(self, other: Vector<bool, N>) -> Vector<bool, N>
Return a new vector with the element-wise and of the vectors
pub fn __expand_and( scope: &mut Scope, this: <Vector<bool, N> as CubeType>::ExpandType, other: <Vector<bool, N> as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<N> Vector<bool, N>where
N: Size,
impl<N> Vector<bool, N>where
N: Size,
Sourcepub fn or(self, other: Vector<bool, N>) -> Vector<bool, N>
pub fn or(self, other: Vector<bool, N>) -> Vector<bool, N>
Return a new vector with the element-wise and of the vectors
pub fn __expand_or( scope: &mut Scope, this: <Vector<bool, N> as CubeType>::ExpandType, other: <Vector<bool, N> as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Sourceimpl<P, N> Vector<P, N>
impl<P, N> Vector<P, N>
pub fn count_ones(self) -> Vector<u32, N>
pub fn __expand_count_ones( scope: &mut Scope, this: <Vector<P, N> as CubeType>::ExpandType, ) -> <Vector<u32, N> as CubeType>::ExpandType