pub struct Sequence<T>where
T: CubeType,{ /* private fields */ }Expand description
A sequence of cube types that is inlined during compilation.
In other words, it allows you to group a dynamic amount of variables at compile time.
All methods push, index and into_iter are executed during compilation and don’t add any overhead on the generated kernel.
Implementations
Sourceimpl<T> Sequence<T>where
T: CubeType,
impl<T> Sequence<T>where
T: CubeType,
Sourcepub fn index(&self, index: usize) -> &T
pub fn index(&self, index: usize) -> &T
Get the variable at the given position in the sequence.
Sourcepub fn index_mut(&mut self, index: usize) -> &mut T
pub fn index_mut(&mut self, index: usize) -> &mut T
Get the variable at the given position in the sequence.
Sourcepub fn __expand_new(_scope: &mut Scope) -> SequenceExpand<T>
pub fn __expand_new(_scope: &mut Scope) -> SequenceExpand<T>
Expand function of new.
Sourcepub fn __expand_push(
scope: &mut Scope,
expand: &mut SequenceExpand<T>,
value: <T as CubeType>::ExpandType,
)
pub fn __expand_push( scope: &mut Scope, expand: &mut SequenceExpand<T>, value: <T as CubeType>::ExpandType, )
Expand function of push.
Sourcepub fn __expand_index(
scope: &mut Scope,
expand: SequenceExpand<T>,
index: usize,
) -> <T as CubeType>::ExpandType
pub fn __expand_index( scope: &mut Scope, expand: SequenceExpand<T>, index: usize, ) -> <T as CubeType>::ExpandType
Expand function of index.
Sourcepub fn __expand_index_mut(
scope: &mut Scope,
expand: SequenceExpand<T>,
index: usize,
) -> <T as CubeType>::ExpandType
pub fn __expand_index_mut( scope: &mut Scope, expand: SequenceExpand<T>, index: usize, ) -> <T as CubeType>::ExpandType
Expand function of index_mut.