TensorMap

Struct TensorMap 

pub struct TensorMap<E, K>{ /* private fields */ }
A CUDA CUtensorMap object. Represents a tensor encoded with a lot of metadata, and is an opaque packed object at runtime. Does not support retrieving any shapes or strides, nor does it give access to the pointer. So these need to be passed separately in an aliased Tensor if needed.

Also see cubecl_runtime::tma.

Implementations

Source

impl<T, K> TensorMap<T, K>
where T: Scalar, K: TensorMapKind,

pub fn coordinate(&self, index: usize, dim: usize) -> usize

Obtain the coordinate corresponding to the given index of the tensor at dimension dim.

A coordinate is a list of indices corresponding to the multi-dimensional position of an element in the tensor. The dim element in a coordinate is the position along the dim dimension of the tensor.

pub fn __expand_coordinate( scope: &Scope, this: &<TensorMap<T, K> as CubeType>::ExpandType, index: <usize as CubeType>::ExpandType, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType

Obtain the coordinate corresponding to the given index of the tensor at dimension dim.

A coordinate is a list of indices corresponding to the multi-dimensional position of an element in the tensor. The dim element in a coordinate is the position along the dim dimension of the tensor.

Source

impl<T, K> TensorMap<T, K>
where T: Scalar, K: TensorMapKind,

pub fn stride(&self, _dim: usize) -> usize

Obtain the stride of input at dimension dim

pub fn shape(&self, _dim: usize) -> usize

Obtain the shape of input at dimension dim

pub fn len(&self) -> usize

The number of vectorized elements in the tensor.

Warning

The length will be affected by the vectorization factor. To obtain the number of elements, you should multiply the length by the vectorization factor.

pub fn buffer_len(&self) -> usize

The length of the buffer representing the tensor in terms of vectorized elements.

Warning

The buffer length will be affected by the vectorization factor. To obtain the number of elements, you should multiply the length by the vectorization factor.

pub fn rank(&self) -> usize

Returns the rank of the tensor.

pub fn downcast<E>(&self) -> TensorMap<E, K>
where E: CubePrimitive,

Downcast the tensormap to the given type and panic if the type isn’t the same.

This function should only be used to satisfy the Rust type system, when two generic types are supposed to be the same.

pub fn __expand_stride( scope: &Scope, expand: NativeExpand<TensorMap<T, K>>, dim: NativeExpand<usize>, ) -> NativeExpand<usize>

pub fn __expand_shape( scope: &Scope, expand: NativeExpand<TensorMap<T, K>>, dim: NativeExpand<usize>, ) -> NativeExpand<usize>

pub fn __expand_len( scope: &Scope, expand: NativeExpand<TensorMap<T, K>>, ) -> NativeExpand<usize>

pub fn __expand_buffer_len( scope: &Scope, expand: NativeExpand<TensorMap<T, K>>, ) -> NativeExpand<usize>

pub fn __expand_rank( scope: &Scope, expand: NativeExpand<TensorMap<T, K>>, ) -> NativeExpand<usize>