pub struct Variable {
pub kind: VariableKind,
pub ty: Type,
}Fields
kind: VariableKindty: TypeImplementations
Sourceimpl Variable
impl Variable
pub fn new(kind: VariableKind, item: Type) -> Variable
pub fn builtin(builtin: Builtin, ty: StorageType) -> Variable
pub fn constant(value: ConstantValue, ty: impl Into<Type>) -> Variable
pub fn elem_type(&self) -> ElemType
pub fn storage_type(&self) -> StorageType
Sourceimpl Variable
impl Variable
Sourcepub fn is_immutable(&self) -> bool
pub fn is_immutable(&self) -> bool
Whether a variable is always immutable. Used for optimizations to determine whether it’s safe to inline/merge
Sourcepub fn is_array(&self) -> bool
pub fn is_array(&self) -> bool
Is this an array type that yields items when indexed, or a scalar/vector that yields elems/slices when indexed?
Sourcepub fn is_memory(&self) -> bool
pub fn is_memory(&self) -> bool
Is this an array type that is contained in concrete memory, or a local array/scalar/vector?
pub fn has_length(&self) -> bool
pub fn has_buffer_length(&self) -> bool
Sourcepub fn is_constant(&self, value: i64) -> bool
pub fn is_constant(&self, value: i64) -> bool
Determines if the value is a constant with the specified value (converted if necessary)